==> llm-docs-0.1.2.tgz: package/docs/development/workflows.md <==
---
id: development-workflows
---
# Development Workflows

<!-- title: Development Workflows -->
<!-- description: Practical guide for development workflows in the Bluefly Platform -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide covers practical development workflows for the Bluefly Platform, including local development, testing, and deployment processes.

## Local Development

### Environment Setup

1. **Prerequisites**
   ```bash
   # Required tools
   node >= 18.0.0
   npm >= 9.0.0
   docker >= 24.0.0
   docker-compose >= 2.20.0
   git >= 2.40.0
   ```

2. **Repository Setup**
   ```bash
   # Clone repositories
   git clone https://gitlab.com/bluefly/platform.git
   git clone https://gitlab.com/bluefly/bfapi.git
   git clone https://gitlab.com/bluefly/bfmcp.git
   
   # Install dependencies
   cd platform
   npm install
   
   # Start development environment
   npm run dev:start
   ```

3. **Environment Variables**
   ```bash
   # .env.local
   NODE_ENV=development
   API_URL=http://localhost:3000
   MCP_URL=http://localhost:3001
   DATABASE_URL=postgresql://postgres:postgres@localhost:5432/bluefly
   REDIS_URL=redis://localhost:6379
   OPENAI_API_KEY=your-api-key
   ANTHROPIC_API_KEY=your-api-key
   ```

### Development Process

1. **Feature Development**
   ```bash
   # Create feature branch
   git checkout -b feature/agent-ui
   
   # Install dependencies
   npm install
   
   # Start development server
   npm run dev
   
   # Run tests
   npm run test:watch
   ```

2. **Code Quality**
   ```bash
   # Lint code
   npm run lint
   
   # Type check
   npm run type-check
   
   # Format code
   npm run format
   
   # Run security audit
   npm audit
   ```

3. **Testing**
   ```bash
   # Unit tests
   npm run test:unit
   
   # Integration tests
   npm run test:integration
   
   # E2E tests
   npm run test:e2e
   
   # Coverage report
   npm run test:coverage
   ```

## Drupal Development

### Module Development

1. **Setup**
   ```bash
   # Install Drupal
   composer create-project drupal/recommended-project drupal
   cd drupal
   
   # Install dependencies
   composer require drupal/bfllm
   composer require drupal/bfmcp
   
   # Enable modules
   drush en bfllm bfmcp
   ```

2. **Development**
   ```bash
   # Start development server
   drush serve
   
   # Clear cache
   drush cr
   
   # Run tests
   phpunit web/modules/custom/bfllm/tests
   ```

3. **Configuration**
   ```yaml
   # bfllm.settings.yml
   bfllm:
     api:
       url: 'http://localhost:3000'
       key: 'your-api-key'
     models:
       default: 'claude-3-opus'
       providers:
         anthropic:
           api_key: 'your-api-key'
         openai:
           api_key: 'your-api-key'
   ```

## API Development

### REST API

1. **Endpoint Development**
   ```typescript
   // src/controllers/agent.controller.ts
   @Controller('agents')
   export class AgentController {
     @Get()
     async list(): Promise<Agent[]> {
       return this.agentService.list();
     }
     
     @Post()
     async create(@Body() input: CreateAgentInput): Promise<Agent> {
       return this.agentService.create(input);
     }
     
     @Get(':id')
     async get(@Param('id') id: string): Promise<Agent> {
       return this.agentService.get(id);
     }
     
     @Put(':id')
     async update(
       @Param('id') id: string,
       @Body() input: UpdateAgentInput
     ): Promise<Agent> {
       return this.agentService.update(id, input);
     }
   }
   ```

2. **Testing**
   ```typescript
   // src/controllers/agent.controller.spec.ts
   describe('AgentController', () => {
     let controller: AgentController;
     let service: AgentService;
     
     beforeEach(async () => {
       const module = await Test.createTestingModule({
         controllers: [AgentController],
         providers: [AgentService]
       }).compile();
       
       controller = module.get(AgentController);
       service = module.get(AgentService);
     });
     
     it('should list agents', async () => {
       const result = await controller.list();
       expect(result).toBeDefined();
     });
   });
   ```

### GraphQL API

1. **Schema Development**
   ```typescript
   // src/schema/agent.schema.ts
   @ObjectType()
   export class Agent {
     @Field()
     id: string;
     
     @Field()
     name: string;
     
     @Field()
     model: string;
     
     @Field()
     status: string;
   }
   
   @Resolver(Agent)
   export class AgentResolver {
     @Query(() => [Agent])
     async agents(): Promise<Agent[]> {
       return this.agentService.list();
     }
     
     @Mutation(() => Agent)
     async createAgent(
       @Arg('input') input: CreateAgentInput
     ): Promise<Agent> {
       return this.agentService.create(input);
     }
   }
   ```

2. **Testing**
   ```typescript
   // src/schema/agent.schema.spec.ts
   describe('AgentResolver', () => {
     let resolver: AgentResolver;
     let service: AgentService;
     
     beforeEach(async () => {
       const module = await Test.createTestingModule({
         providers: [AgentResolver, AgentService]
       }).compile();
       
       resolver = module.get(AgentResolver);
       service = module.get(AgentService);
     });
     
     it('should query agents', async () => {
       const result = await resolver.agents();
       expect(result).toBeDefined();
     });
   });
   ```

## Integration Development

### LLM Integration

1. **Provider Development**
   ```typescript
   // src/providers/anthropic.provider.ts
   @Injectable()
   export class AnthropicProvider implements ModelProvider {
     async execute(
       model: string,
       input: string,
       config: any
     ): Promise<any> {
       const client = new Anthropic({
         apiKey: config.apiKey
       });
       
       const response = await client.messages.create({
         model,
         messages: [{ role: 'user', content: input }],
         max_tokens: config.maxTokens
       });
       
       return response.content;
     }
   }
   ```

2. **Testing**
   ```typescript
   // src/providers/anthropic.provider.spec.ts
   describe('AnthropicProvider', () => {
     let provider: AnthropicProvider;
     
     beforeEach(() => {
       provider = new AnthropicProvider();
     });
     
     it('should execute model', async () => {
       const result = await provider.execute(
         'claude-3-opus',
         'Hello, Claude!',
         { apiKey: 'test-key' }
       );
       expect(result).toBeDefined();
     });
   });
   ```

### Drupal Integration

1. **Module Development**
   ```php
   // src/Plugin/ModelProvider/DrupalProvider.php
   namespace Drupal\bfllm\Plugin\ModelProvider;
   
   use Drupal\Core\Plugin\PluginBase;
   use Drupal\bfllm\ModelProviderInterface;
   
   /**
    * @ModelProvider(
    *   id = "drupal",
    *   label = @Translation("Drupal Provider")
    * )
    */
   class DrupalProvider extends PluginBase implements ModelProviderInterface {
     public function execute(string $model, string $input, array $config): array {
       $client = \Drupal::httpClient();
       
       $response = $client->post('http://localhost:3000/api/execute', [
         'json' => [
           'model' => $model,
           'input' => $input,
           'config' => $config
         ]
       ]);
       
       return json_decode($response->getBody(), TRUE);
     }
   }
   ```

2. **Testing**
   ```php
   // tests/src/Unit/Plugin/ModelProvider/DrupalProviderTest.php
   namespace Drupal\Tests\bfllm\Unit\Plugin\ModelProvider;
   
   use Drupal\Tests\UnitTestCase;
   use Drupal\bfllm\Plugin\ModelProvider\DrupalProvider;
   
   class DrupalProviderTest extends UnitTestCase {
     public function testExecute() {
       $provider = new DrupalProvider([], 'drupal', []);
       
       $result = $provider->execute(
         'drupal-11',
         'Hello, Drupal!',
         []
       );
       
       $this->assertNotEmpty($result);
     }
   }
   ```

## Best Practices

1. **Code Quality**
   - Write tests first
   - Follow style guide
   - Document code
   - Review changes

2. **Development Process**
   - Use feature branches
   - Write commit messages
   - Create merge requests
   - Review code

3. **Testing**
   - Unit tests
   - Integration tests
   - E2E tests
   - Performance tests

4. **Documentation**
   - Update README
   - Write API docs
   - Document changes
   - Add examples

## Related Documentation

- [Architecture Guide](../architecture/README)
- [API Guide](../api/README)
- [Testing Guide](../testing/README)
- [Deployment Guide](../deployment/README)
- [Security Guide](../security/README)

==> llm-docs-0.1.4.tgz: package/docs/development/workflows.md <==
---
id: development-workflows
---
# Development Workflows

<!-- title: Development Workflows -->
<!-- description: Practical guide for development workflows in the LLM Platform Platform -->
<!-- lastUpdated: 2024-03-19 -->

## Overview

This guide covers practical development workflows for the LLM Platform Platform, including local development, testing, and deployment processes.

## Local Development

### Environment Setup

1. **Prerequisites**
   ```bash
   # Required tools
   node >= 18.0.0
   npm >= 9.0.0
   docker >= 24.0.0
   docker-compose >= 2.20.0
   git >= 2.40.0
   ```

2. **Repository Setup**
   ```bash
   # Clone repositories
   git clone https://gitlab.com/bluefly/platform.git
   git clone https://gitlab.com/bluefly/bfapi.git
   git clone https://gitlab.com/bluefly/llm-mcp.git
   
   # Install dependencies
   cd platform
   npm install
   
   # Start development environment
   npm run dev:start
   ```

3. **Environment Variables**
   ```bash
   # .env.local
   NODE_ENV=development
   API_URL=http://localhost:3000
   MCP_URL=http://localhost:3001
   DATABASE_URL=postgresql://postgres:postgres@localhost:5432/bluefly
   REDIS_URL=redis://localhost:6379
   OPENAI_API_KEY=your-api-key
   ANTHROPIC_API_KEY=your-api-key
   ```

### Development Process

1. **Feature Development**
   ```bash
   # Create feature branch
   git checkout -b feature/agent-ui
   
   # Install dependencies
   npm install
   
   # Start development server
   npm run dev
   
   # Run tests
   npm run test:watch
   ```

2. **Code Quality**
   ```bash
   # Lint code
   npm run lint
   
   # Type check
   npm run type-check
   
   # Format code
   npm run format
   
   # Run security audit
   npm audit
   ```

3. **Testing**
   ```bash
   # Unit tests
   npm run test:unit
   
   # Integration tests
   npm run test:integration
   
   # E2E tests
   npm run test:e2e
   
   # Coverage report
   npm run test:coverage
   ```

## Drupal Development

### Module Development

1. **Setup**
   ```bash
   # Install Drupal
   composer create-project drupal/recommended-project drupal
   cd drupal
   
   # Install dependencies
   composer require drupal/bfllm
   composer require drupal/llm-mcp
   
   # Enable modules
   drush en bfllm llm-mcp
   ```

2. **Development**
   ```bash
   # Start development server
   drush serve
   
   # Clear cache
   drush cr
   
   # Run tests
   phpunit web/modules/custom/bfllm/tests
   ```

3. **Configuration**
   ```yaml
   # bfllm.settings.yml
   bfllm:
     api:
       url: 'http://localhost:3000'
       key: 'your-api-key'
     models:
       default: 'claude-3-opus'
       providers:
         anthropic:
           api_key: 'your-api-key'
         openai:
           api_key: 'your-api-key'
   ```

## API Development

### REST API

1. **Endpoint Development**
   ```typescript
   // src/controllers/agent.controller.ts
   @Controller('agents')
   export class AgentController {
     @Get()
     async list(): Promise<Agent[]> {
       return this.agentService.list();
     }
     
     @Post()
     async create(@Body() input: CreateAgentInput): Promise<Agent> {
       return this.agentService.create(input);
     }
     
     @Get(':id')
     async get(@Param('id') id: string): Promise<Agent> {
       return this.agentService.get(id);
     }
     
     @Put(':id')
     async update(
       @Param('id') id: string,
       @Body() input: UpdateAgentInput
     ): Promise<Agent> {
       return this.agentService.update(id, input);
     }
   }
   ```

2. **Testing**
   ```typescript
   // src/controllers/agent.controller.spec.ts
   describe('AgentController', () => {
     let controller: AgentController;
     let service: AgentService;
     
     beforeEach(async () => {
       const module = await Test.createTestingModule({
         controllers: [AgentController],
         providers: [AgentService]
       }).compile();
       
       controller = module.get(AgentController);
       service = module.get(AgentService);
     });
     
     it('should list agents', async () => {
       const result = await controller.list();
       expect(result).toBeDefined();
     });
   });
   ```

### GraphQL API

1. **Schema Development**
   ```typescript
   // src/schema/agent.schema.ts
   @ObjectType()
   export class Agent {
     @Field()
     id: string;
     
     @Field()
     name: string;
     
     @Field()
     model: string;
     
     @Field()
     status: string;
   }
   
   @Resolver(Agent)
   export class AgentResolver {
     @Query(() => [Agent])
     async agents(): Promise<Agent[]> {
       return this.agentService.list();
     }
     
     @Mutation(() => Agent)
     async createAgent(
       @Arg('input') input: CreateAgentInput
     ): Promise<Agent> {
       return this.agentService.create(input);
     }
   }
   ```

2. **Testing**
   ```typescript
   // src/schema/agent.schema.spec.ts
   describe('AgentResolver', () => {
     let resolver: AgentResolver;
     let service: AgentService;
     
     beforeEach(async () => {
       const module = await Test.createTestingModule({
         providers: [AgentResolver, AgentService]
       }).compile();
       
       resolver = module.get(AgentResolver);
       service = module.get(AgentService);
     });
     
     it('should query agents', async () => {
       const result = await resolver.agents();
       expect(result).toBeDefined();
     });
   });
   ```

## Integration Development

### LLM Integration

1. **Provider Development**
   ```typescript
   // src/providers/anthropic.provider.ts
   @Injectable()
   export class AnthropicProvider implements ModelProvider {
     async execute(
       model: string,
       input: string,
       config: any
     ): Promise<any> {
       const client = new Anthropic({
         apiKey: config.apiKey
       });
       
       const response = await client.messages.create({
         model,
         messages: [{ role: 'user', content: input }],
         max_tokens: config.maxTokens
       });
       
       return response.content;
     }
   }
   ```

2. **Testing**
   ```typescript
   // src/providers/anthropic.provider.spec.ts
   describe('AnthropicProvider', () => {
     let provider: AnthropicProvider;
     
     beforeEach(() => {
       provider = new AnthropicProvider();
     });
     
     it('should execute model', async () => {
       const result = await provider.execute(
         'claude-3-opus',
         'Hello, Claude!',
         { apiKey: 'test-key' }
       );
       expect(result).toBeDefined();
     });
   });
   ```

### Drupal Integration

1. **Module Development**
   ```php
   // src/Plugin/ModelProvider/DrupalProvider.php
   namespace Drupal\bfllm\Plugin\ModelProvider;
   
   use Drupal\Core\Plugin\PluginBase;
   use Drupal\bfllm\ModelProviderInterface;
   
   /**
    * @ModelProvider(
    *   id = "drupal",
    *   label = @Translation("Drupal Provider")
    * )
    */
   class DrupalProvider extends PluginBase implements ModelProviderInterface {
     public function execute(string $model, string $input, array $config): array {
       $client = \Drupal::httpClient();
       
       $response = $client->post('http://localhost:3000/api/execute', [
         'json' => [
           'model' => $model,
           'input' => $input,
           'config' => $config
         ]
       ]);
       
       return json_decode($response->getBody(), TRUE);
     }
   }
   ```

2. **Testing**
   ```php
   // tests/src/Unit/Plugin/ModelProvider/DrupalProviderTest.php
   namespace Drupal\Tests\bfllm\Unit\Plugin\ModelProvider;
   
   use Drupal\Tests\UnitTestCase;
   use Drupal\bfllm\Plugin\ModelProvider\DrupalProvider;
   
   class DrupalProviderTest extends UnitTestCase {
     public function testExecute() {
       $provider = new DrupalProvider([], 'drupal', []);
       
       $result = $provider->execute(
         'drupal-11',
         'Hello, Drupal!',
         []
       );
       
       $this->assertNotEmpty($result);
     }
   }
   ```

## Best Practices

1. **Code Quality**
   - Write tests first
   - Follow style guide
   - Document code
   - Review changes

2. **Development Process**
   - Use feature branches
   - Write commit messages
   - Create merge requests
   - Review code

3. **Testing**
   - Unit tests
   - Integration tests
   - E2E tests
   - Performance tests

4. **Documentation**
   - Update README
   - Write API docs
   - Document changes
   - Add examples

## Related Documentation

- [Architecture Guide](../architecture/README)
- [API Guide](../api/README)
- [Testing Guide](../testing/README)
- [Deployment Guide](../deployment/README)
- [Security Guide](../security/README)
